from styled_print import styled_print


styled_print("hello", {
    "color": "red",
    "styles": ["bold"],
    "bg_color": "on_white",
    "uppercase": True,
    "align": "center",
    "padding": 2,
    "border": False
})
styled_print("hello", {
    "color": "red",
    "styles": ["bold"],
    "bg_color": "on_red",
    "uppercase": True,
    "align": "center",
    "padding": 2,
    "border": True
})
styled_print("hello", {
    "color": "red",
    "styles": ["bold"],
    "uppercase": True,
    "align": "left",
    "padding": 2,
    "border": False
})
styled_print("hello", {
    "color": "yellow",
    "styles": ["underline"],
    "uppercase": True,
    "align": "left",
    "border": False
})



from setuptools import setup, find_packages

setup(
    name='styled_print',
    version='0.1.3',  
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=[
        'termcolor',  
    ],
    author='Usmonov Shoxruxmirzo',
    author_email='usmonovshohruxmirzo@gmail.com',
    description='A flexible terminal text styling utility for color, background, and custom formatting options.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/webbro-software/styled_print',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)


from termcolor import colored

def styled_print(string, options):
    color = options.get("color")
    styles = options.get("styles", [])
    bg_color = options.get("bg_color")
    uppercase = options.get("uppercase", False)
    lowercase = options.get("lowercase", False)
    align = options.get("align", "left") 
    padding = options.get("padding", 0)
    border = options.get("border", False) 

    if uppercase:
        string = string.upper()
    elif lowercase:
        string = string.lower()

    string = f"{' ' * padding}{string}{' ' * padding}"

    if align == "center":
        string = string.center(50) 
    elif align == "right":
        string = string.rjust(50)

    styled_text = colored(string, color, on_color=bg_color, attrs=styles)

    if border:
        border_line = "-" * (len(string) + 4)
        print(border_line)
        print(f"| {styled_text} |")
        print(border_line)
    else:
        print(styled_text)